diff lisp/allout.el @ 47127:895cc47caf77

(my-mark-marker): Fix typo.
author Juanma Barranquero <lekktu@gmail.com>
date Fri, 30 Aug 2002 11:03:28 +0000
parents 29f1f32aee5b
children e7aab76fa215
line wrap: on
line diff
--- a/lisp/allout.el	Fri Aug 30 11:02:54 2002 +0000
+++ b/lisp/allout.el	Fri Aug 30 11:03:28 2002 +0000
@@ -5,7 +5,7 @@
 ;; Author: Ken Manheimer <klm@python.org>
 ;; Maintainer: Ken Manheimer <klm@python.org>
 ;; Created: Dec 1991 - first release to usenet
-;; Version: $Id: allout.el,v 1.32 2002/03/27 20:13:03 pj Exp $||
+;; Version: $Id: allout.el,v 1.33 2002/07/03 13:19:13 lektu Exp $||
 ;; Keywords: outlines mode wp languages
 
 ;; This file is part of GNU Emacs.
@@ -509,7 +509,7 @@
 ;;;_  : Version
 ;;;_   = outline-version
 (defvar outline-version
-  (let ((rcs-rev "$Revision: 1.32 $"))
+  (let ((rcs-rev "$Revision: 1.33 $"))
     (condition-case err
 	(save-match-data
 	  (string-match "Revision: \\([0-9]+\\.[0-9]+\\)" rcs-rev)
@@ -4729,9 +4729,9 @@
 	       (if append
 		   (nconc (symbol-value hook) (list function))
 		 (cons function (symbol-value hook)))))))
 ;;;_  : my-mark-marker to accomodate divergent emacsen:
 (defun my-mark-marker (&optional force buffer)
-  "Accomodate the different signature for mark-marker across emacsen.
+  "Accommodate the different signature for mark-marker across emacsen.
 
 GNU XEmacs takes two optional args, while mainline GNU Emacs does not,
 so pass them along when appropriate."
@@ -4729,9 +4729,9 @@
 		   (nconc (symbol-value hook) (list function))
 		 (cons function (symbol-value hook)))))))
-;;;_  : my-mark-marker to accomodate divergent emacsen:
+;;;_  : my-mark-marker to accommodate divergent emacsen:
 (defun my-mark-marker (&optional force buffer)